SpiTransferProperties class

Annotations
  • @immutable

Constructors

SpiTransferProperties({int? speedHz, Duration delay = const Duration(microseconds: 0), int? bitsPerWord, bool doToggleCS = false, SpiTransferMode? txTransferMode, SpiTransferMode? rxTransferMode, Duration wordDelay = const Duration(microseconds: 0)})

Properties

bitsPerWord → int?
Select a bits_per_word other than the device default for this transfer. If 0 the default of the SPI device is used.
final
delay → Duration
Delay after this transfer before (optionally) changing the chipselect status, then starting the next transfer or completing this RawSpiTransfer. Measured in microseconds.
final
doToggleCS → bool
Affects chipselect after this transfer completes.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rxTransferMode → SpiTransferMode?
number of bits used for reading. If 0 the default (SPI_NBITS_SINGLE) is used.
final
speedHz → int?
Select a speed other than the device default for this transfer. If 0, the default of the SPI device is used.
final
txTransferMode → SpiTransferMode?
Number of bits used for writing. If 0 the default (SPI_NBITS_SINGLE) is used.
final
wordDelay → Duration
Delay to be inserted between consecutive words of a transfer
final

Methods

nbitsFromTransferMode(SpiTransferMode? mode) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultProperties → SpiTransferProperties
final