SpidevHandle class

A wrapper around a linux spidev.

Communicates with one single SPI slave.

Properties

bitsPerWord ↔ int
Gets the default number of bits per word for this SpidevHandle.
getter/setter pair
flags ↔ Set<SpiFlag>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isOpen → bool
no setter
maxSpeed ↔ int
getter/setter pair
mode ↔ SpiMode
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spidev → Spidev
final

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transfer(List<SpiTransfer<SpiTransferData>> transfers) → Future<void>
transferNativeMem(List<SpiTransfer<NativeMemSpiTransferData>> transfers) → Future<void>
transferSingleByteLists({List<int>? txBuf, List<int>? rxBuf, SpiTransferProperties? transferProperties}) → Future<void>
transferSingleNativeMem({Pointer<NativeType>? txBuf, Pointer<NativeType>? rxBuf, required int length, SpiTransferProperties? transferProperties}) → Future<void>
transferSingleTypedData({Uint8List? txBuf, Uint8List? rxBuf, SpiTransferProperties? transferProperties}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited